pub struct CLIGlobalOptions {
pub colors: Option<ColorsArg>,
pub verbose: bool,
pub log_level: LogLevel,
}Expand description
Global options applied to all commands
Fields
colors: Option<ColorsArg>Set the formatting mode for markup: “off” prints everything as plain text, “force” forces the formatting of markup using ANSI even if the console output is determined to be incompatible
verbose: boolPrint additional diagnostics, and some diagnostics show more information. Also, print out what files were processed and which ones were modified.
log_level: LogLevelThe level of logging. In order, from the most verbose to the least verbose: debug, info, warn, error.